window.onload = function () {
  var spread = new GC.Spread.Sheets.Workbook(document.getElementById("ss"), {
    sheetCount: 0,
  });
  initSpread(spread);
};

let disableRows = new Set([0, 1])

let oldOpenDateTimeCmd = GC.Spread.Sheets.Commands.openDateTimePicker.execute;
GC.Spread.Sheets.Commands.openDateTimePicker.execute = function () {
  let options = arguments[1]
  if (disableRows.has(options.row)) return false;
  return oldOpenDateTimeCmd.apply(this, arguments)
}

function initSpread(spread) {
  spread.suspendPaint();
  spread.options.autoFitType = GC.Spread.Sheets.AutoFitType.cellWithHeader;
  var dataManager = spread.dataManager();
  initDefineOrderTable(spread, dataManager);
  spread.resumePaint();
}

function initDefineOrderTable(spread, dataManager) {
  spread.options.allowDynamicArray = true;

  var orderTable = dataManager.addTable("orderTable", {
    data: [
      {
        description: "Mow grass",
        dueDate: undefined,
        priority: "High",
        assignedTo: "Dad",
        isFinished: "Yes",
        isEncouraged: "False",
        credit: "20,75",
      },
      {
        description: "Clean Room",
        dueDate: "8/9/2021",
        priority: "Medium",
        assignedTo: "Daughter",
        isFinished: "No",
        isEncouraged: "True",
        credit: "10,50",
      },
      {
        description: "Organize Pantry",
        dueDate: new Date(2024, 11, 20),
        priority: "Low",
        assignedTo: "Son",
        isFinished: "Yes",
        isEncouraged: "True",
        credit: "10,75",
      },
      {
        description: "Prepare BBQ",
        dueDate: "22/12/2024",
        priority: "High",
        assignedTo: "Mom",
        isFinished: "No",
        isEncouraged: "False",
        credit: "30,25",
      },
    ],
    schema: {
      columns: {
        dueDate: { dataType: "date", dataPattern: "yyyy/mm/dd" },
        isFinished: { dataPattern: "Yes|No" },
        isEncouraged: { dataType: "boolean", dataPattern: "True|False" },
        credit: { dataType: "number", dataPattern: "." },
      },
    },
  });

  var tableSheet = spread.addSheetTab(
    0,
    "Orders",
    GC.Spread.Sheets.SheetType.tableSheet
  );
  tableSheet.options.allowAddNew = true;
  tableSheet.options.enableDefineColumn = true;

  const defaultDateLimitedStyle = new GC.Spread.Sheets.Style();
  defaultDateLimitedStyle.formatter = "yyyy/mm/dd"
  defaultDateLimitedStyle.hAlign = "left"
  defaultDateLimitedStyle.cellButtons = [
    {
      imageType: GC.Spread.Sheets.ButtonImageType.dropdown,
      command: "openDateTimePicker",
      useButtonStyle: true,
    }
  ];
  defaultDateLimitedStyle.dropDowns = [
    {
      type: GC.Spread.Sheets.DropDownType.dateTimePicker,
      option: {
        showTime: true,
        minDate: new Date('2024/12/1'),
        maxDate: new Date('2024/12/31')
      }
    }
  ];

  var orderView = orderTable.addView("orderView", [
    { value: "description", width: 80 },
    //date-time-picker-column
    {
      value: "dueDate",
      dataType: "date",
      width: 150,
      style: defaultDateLimitedStyle
    },
    { value: "priority", width: 80 },
    { value: "assignedTo", width: 80 },
    { value: "isFinished", width: 80 },
    { value: "isEncouraged", width: 80 },
    { value: "credit", width: 80 },
  ]);

  orderView.fetch().then(function () {
    tableSheet.setDataView(orderView);
  });
}
